@@ -11,7 +11,7 @@ from ..validations import validate_series_has_minimum_length
 
 @check_types
 def extreme(data: pd.Series, alpha: float = 0.05, bc_relaxation: float = 0.167, poly_order: int = 3):
-    """Extreme outliers removal
+    r"""Extreme outliers removal
 
     Outlier detector and removal based on the `paper from Gustavo A. Zarruk
     <https://iopscience.iop.org/article/10.1088/0957-0233/16/10/012/meta>`_. The procedure is as follows:
@@ -26,16 +26,17 @@ def extreme(data: pd.Series, alpha: float = 0.05, bc_relaxation: float = 0.167,
     the predictor function each time.
 
     Args:
-        data (pandas.Series): Time series
-        alpha (float, optional): Significance level
+        data (pandas.Series): Time Series.
+        alpha (float, optional): Significance level.
             is a number higher than or equal to 0 and lower than 1. In statistics, the significance level is the
             probability of rejecting the null hypothesis when true. For example, a significance level of 0.05 means that
             there is a 5% risk detecting an outlier that is not a true outlier.
-        bc_relaxation (float, optional): Relaxation factor
+        bc_relaxation (float, optional): Relaxation factor.
             for the Bonferroni critical value. Smaller values will make anomaly detection more conservative. Defaults
             to 1/6.
-        poly_order (int, optional): Polynomial order
-            the regression function fitted to the original time series. Defaults to 3.
+        poly_order (int, optional): Polynomial order.
+            It represents the order of the polynomial function fitted to the original time series.
+            Defaults to 3.
 
     Returns:
         pandas.Series: Time series without outliers.
