@@ -120,12 +120,19 @@ class DataQualityScoreAnalyser(ABC):
 
         Returns:
             DataQualityScore: A DataQualityScore object
+
+        raises:
+            UserValueError: If analysis_start < analysis_end
+            UserValueError: If the analysis start and end timestamps are outside the range of the series index
         """
         if analysis_start > analysis_end:
             raise UserValueError(
                 f"Expected analysis_start < analysis_end, got analysis_start '{analysis_start}' and analysis_end '{analysis_end}'"
             )
 
+        if len(self.series) < 1:
+            return  # type: ignore
+
         if analysis_start < self.series.index[0]:
             raise UserValueError(
                 f"Expected analysis_start to be equal or after the first timestamp in series, got analysis_start={analysis_start} and series.index[0]={self.series.index[0]}"
@@ -146,23 +153,10 @@ class DataQualityScoreAnalyser(ABC):
 
     @staticmethod
     def _filter_events_outside_analysis_period(
-        gaps: List[Tuple[pd.Timestamp, pd.Timestamp]], analysis_start: pd.Timestamp, analysis_end: pd.Timestamp
+        events: List[Tuple[pd.Timestamp, pd.Timestamp]], analysis_start: pd.Timestamp, analysis_end: pd.Timestamp
     ) -> List[Tuple[pd.Timestamp, pd.Timestamp]]:
 
-        # Find index of first gap that ends within analysis period
-        idx_start = 0
-        for idx_start, (_, gap_end) in enumerate(gaps):
-            if gap_end > analysis_start:
-                break
-
-        # Find index (by traversing the gaps from last to first) of last gap that starts within analysis period
-        idx_end = 0
-        for idx_end, (gap_start, _) in enumerate(reversed(gaps)):
-            if gap_start < analysis_end:
-                break
-        idx_end = len(gaps) - idx_end
-
-        return gaps[idx_start:idx_end]
+        return [(start, end) for start, end in events if end > analysis_start and start < analysis_end]
 
     @staticmethod
     def _limit_first_and_last_events_to_analysis_period(
