@@ -3,12 +3,13 @@ import numba
 import numpy as np
 import pandas as pd
 
-from cognite.client.utils import timestamp_to_ms
 from scipy import stats
 
 from indsl.detect.change_point_detector import ed_pelt
 from indsl.detect.utils import constrain, resample_timeseries
 
+from ..exceptions import UserValueError
+
 # Detectors
 from ..type_check import check_types
 from ..validations import validate_series_has_time_index
@@ -51,7 +52,7 @@ def ssd_cpd(
 
     # store the arrays with datapoints and timestamp (in ms since epoch)
     y: np.ndarray = data_resampled.values
-    x: np.ndarray = np.array([timestamp_to_ms(item) for item in data_resampled.index])
+    x: np.ndarray = data_resampled.index.to_numpy("datetime64[ms]").view(np.int64)
 
     # the maximum allowable distance is half the number of datapoints
     max_distance: int = int(np.floor(len(x) / 2))
@@ -147,12 +148,12 @@ def ssid(data: pd.Series, ratio_lim: float = 2.5, alpha1: float = 0.2, alpha2: f
     Ls = int(min(len(data) * 0.05, 50))
 
     if Ls < 10:
-        raise RuntimeError("There are too few datapoints to detect steady states.")
+        raise UserValueError("There are too few datapoints to detect steady states.")
 
     # Check the bounds of alpha parameters
     for par, par_val in zip([alpha1, alpha2, alpha3], ["alpha1", "alpha2", "alpha3"]):
         if not (0 <= par <= 1):
-            raise RuntimeError(f"Alpha parameters should be between 0 and 1. Received {par_val} for {par}")
+            raise UserValueError(f"Alpha parameters should be between 0 and 1. Received {par_val} for {par}")
 
     # Split data into first sample points and rest of the data
     data_ini = data[0:Ls]
