@@ -6,6 +6,8 @@ import pandas as pd
 from indsl.resample.auto_align import auto_align
 from indsl.type_check import check_types
 
+from ..exceptions import UserRuntimeError
+
 
 CONVERT_R_TO_K = 5 / 9  # conversion from R to K
 CONVERT_PSI_TO_KPA = 6.8947  # conversion from psi to kpa
@@ -28,17 +30,17 @@ def calculate_gas_density(
     is used to calculate the gas density.
 
     Args:
-       pressure (pandas.Series): Pressure [psi]
+       pressure (pandas.Series): Pressure [psi].
            Pressure time series in psi units.
-       temperature (pandas.Series): Temperature [degF]
+       temperature (pandas.Series): Temperature [degF].
            Temperature time series in degrees Fahrenheit units.
-       sg (pd.Series) : Specific gravity [-]
+       sg (pd.Series) : Specific gravity [-].
            Specific gravity of the gas.
        align_timesteps (bool): Auto-align
           Automatically align time stamp  of input time series. Default is False.
     Returns:
-       pandas.Series: Gas density [lbf/ft3]
-           Estimated gas density in pound-force per cubic foot (pcf).
+       pandas.Series: Gas density [lbm/ft3]
+           Estimated gas density in pound-mass per cubic foot (pcf).
     Raises:
        RuntimeError: When all values of the pressure and temperature are out of range for calculating compressibility.
 
@@ -152,7 +154,7 @@ def calculate_compressibility(Ppr: pd.Series, Tpr: pd.Series):
        pandas.Series: Compressibility factor
             Non-dimensional series.
     Raises:
-       RuntimeError: When all values of the pressure and temperature are out of range for calculating compressibility.
+       UserRuntimeError: When all values of the pressure and temperature are out of range for calculating compressibility.
     """
     # delete points that are out of range, raise error if empty
     Tpr = Tpr[(Tpr.values >= 1) & (Tpr.values <= 3)]
@@ -161,7 +163,7 @@ def calculate_compressibility(Ppr: pd.Series, Tpr: pd.Series):
     Tpr, Ppr = Tpr.loc[idx], Ppr.loc[idx]
 
     if Tpr.empty or Ppr.empty:
-        raise RuntimeError("Pressure and Temperature data are empty or out of range")
+        raise UserRuntimeError("Pressure and Temperature data are empty or out of range")
 
     A = 1.39 * (Tpr - 0.92) ** 0.5 - 0.36 * Tpr - 0.10
     E = 9 * (Tpr - 1)
