@@ -50,6 +50,7 @@ def reindex(
     This method offers data reindexing onto a common index and fills missing data points.
     If bounded is false, the common index is the union of the the input time-series indices.
     If bounded is true, the common index is restricted to the period where the time-series overlap.
+    All not-a-number (NaN) values are removed in the output time series.
 
     Args:
         data1 (pandas.Series): First time series.
@@ -101,6 +102,10 @@ def reindex_many(
     bounded: bool = False,
 ) -> List[pd.Series]:
 
+    # Nothing to do if data contains less than 2 series
+    if len(data) < 2:
+        return data
+
     # Return if all indices are already aligned and
     # none of the input series contain NaNs
     indices = [d.index for d in data]
@@ -112,12 +117,15 @@ def reindex_many(
         raise UserTypeError("Only DateTimeIndex index supported.")
 
     # Check validity of input time series
-    if any([len(d.dropna()) <= 2 for d in data]):
+    if any([len(d.dropna()) < 2 for d in data]):
         raise UserValueError("One of the time series has less than two values.")
 
-    # Nothing to do if data contains less than 2 series
-    if len(data) < 2:
-        return data
+    # If bounded=True, we need to remove Nan values here.
+    # Otherwise, we might end up extrapolating if there are NaN values at
+    # the beginning/end of a time-series (which is in conflict with the bounded=True flag)
+    if bounded:
+        data = [d.dropna() for d in data]
+        indices = [d.index for d in data]
 
     # Get the union of the indices
     idx_common = indices[0]
