@@ -60,6 +60,35 @@ def line(
     return pd.Series(data=line_data, index=idx, name="Line")
 
 
+@check_types
+def const_value(
+    value: float = 0,
+) -> pd.Series:
+    """Constant value
+
+    This function generates a horizontal line. The assumptions when generating the horizontal line
+    is that the start date is set as "1970-01-01", the end date is set as "now" and the sampling is "1 week".
+    If the number of data points generated exceeds 100000 then the start date is moved forward, such that the
+    number of data points generated is not greater than 100000 with "1 week" sampling resolution.
+
+    Args:
+        value (float): Value.
+                value. Defaults to 0.
+    Returns:
+        pandas.Series: Time series.
+            Synthetic time series for a line
+
+    """
+    sample_freq = pd.Timedelta(weeks=1)
+    slope = 0
+    idx = _make_index(start="1970-01-01", end="now", freq=sample_freq)
+    if len(idx) > 1e8:
+        idx = idx[len(idx) - 100000 :]
+
+    line_data = _time_array(idx) * slope + value
+    return pd.Series(data=line_data, index=idx, name="Constant value")
+
+
 def sine_wave(
     start_date: Optional[pd.Timestamp] = None,
     end_date: Optional[pd.Timestamp] = None,
