@@ -34,7 +34,7 @@ def time_string_to_ms(pattern, string, unit_in_ms):
 def granularity_to_ms(granularity: str) -> int:
     ms = time_string_to_ms(r"(\d+)({})", granularity, _unit_in_ms_without_week)
     if ms is None:
-        raise ValueError(
+        raise UserValueError(
             "Invalid granularity format: `{}`. Must be on format <integer>(s|m|h|d). E.g. '5m', '3h' or '1d'.".format(
                 granularity
             )
@@ -48,7 +48,7 @@ def time_ago_to_ms(time_ago_string: str) -> int:
         return 0
     ms = time_string_to_ms(r"(\d+)({})-ago", time_ago_string, _unit_in_ms)
     if ms is None:
-        raise ValueError(
+        raise UserValueError(
             "Invalid time-ago format: `{}`. Must be on format <integer>(s|m|h|d|w)-ago or 'now'. E.g. '3d-ago' or '1w-ago'.".format(
                 time_ago_string
             )
@@ -297,14 +297,14 @@ def fill_gaps(
     try:
         granularity_timedelata = pd.Timedelta(granularity)
     except ValueError:
-        raise ValueError(f"Unable to convert {granularity} to time resolution", RuntimeWarning)
+        raise UserValueError(f"Unable to convert {granularity} to time resolution", RuntimeWarning)
 
     small_gap = 0
     if ffill_resolution:
         try:
             small_gap = granularity_timedelata / pd.Timedelta(ffill_resolution)
         except (ValueError, ZeroDivisionError):
-            raise ValueError(f"Unable to convert {ffill_resolution} to time resolution", RuntimeWarning)
+            raise UserValueError(f"Unable to convert {ffill_resolution} to time resolution", RuntimeWarning)
 
     inter_gap = None
     mask_gap = 0
@@ -313,7 +313,7 @@ def fill_gaps(
             mask_gap = granularity_timedelata / pd.Timedelta(interpolate_resolution)
             inter_gap = int(mask_gap)
         except (ValueError, ZeroDivisionError):
-            raise ValueError(f"Unable to convert {interpolate_resolution} to time resolution", RuntimeWarning)
+            raise UserValueError(f"Unable to convert {interpolate_resolution} to time resolution", RuntimeWarning)
 
     # ffill all, after interpolate and adding noise
     # create groups based on size of gap
@@ -338,3 +338,19 @@ def fill_gaps(
 def number_of_events(out: pd.Series):
     """Calculate the number of events detected from a step time series."""
     return len(np.where(out.values == 1)[0]) / 2
+
+
+def scalar_to_pandas_series(data: Union[float, pd.Series]) -> pd.Series:
+    """Convert data to series if it is not already.
+
+    Args:
+        data: Data that needs to be series.
+
+    Returns:
+        pd.Series: Data as series.
+    """
+    if isinstance(data, float):
+        # IDEA: Use const_value function instead, but have to avoid circular import
+        # Needs at least two values covering the whole time span of interest to work with auto_align
+        data = pd.Series(data, index=pd.date_range(start="1970", end=pd.Timestamp.now(), periods=2))
+    return data
