@@ -1,11 +1,13 @@
 # Copyright 2021 Cognite AS
 
 from datetime import datetime, timedelta
-from typing import List, Literal, Optional
+from typing import List, Literal, Optional, Tuple
 
 import numpy as np
 import pandas as pd
 
+from scipy.stats import shapiro
+
 from indsl.resample.auto_align import auto_align
 
 from ..exceptions import UserValueError
@@ -331,10 +333,23 @@ def generate_step_series(flag: pd.Series) -> pd.Series:
     Construct a step-wise time series (with 0-1 values) from a flag time series.
 
     Args:
-        flag (pd.Series): Binary time series
+        flag (pd.Series): Binary time series.
+            The length of the flag time series has to be the same as the original data points.
 
     Returns:
         pd.Series: Time series
+
+    Example:
+        Given 4 datapoints and a flag with values [0, 0, 1, 0]
+
+            data points: x-------x-------x-------x
+            flag:        0       0       1       0
+
+        The resulting step series is represented as:
+
+                                         x-------x
+            step series: x---------------x
+                         0               01      1
     """
     # add first point as the start of the step time series
     step_time_series = pd.Series([flag[0]], index=[flag.index[0]])
@@ -404,3 +419,143 @@ def create_series_from_timesteps(timesteps: List[timedelta]) -> pd.Series:
         timestamps.append(timestamps[-1] + step)
     timestamps = pd.Series(timestamps)
     return pd.Series(np.zeros(len(timestamps)), index=timestamps)
+
+
+def normality_assumption_test(
+    series: pd.Series, max_data_points: int = 5000, min_p_value: float = 0.05, min_W: float = 0.5
+) -> Tuple[float, float]:
+    """Test for normality assumption
+
+    This function performs a Shapiro-Wilk test to check if the data is normally distributed.
+
+    Args:
+        series (pd.Series): Time series
+        max_data_points (int, optional): Maximum number of data points.
+            The test is only performed if the time series contains less data points than this value.
+            Default to 5000.
+        min_p_value (float, optional): Minimum p value.
+            Probability of the time series not being normally distributed.
+            Default to 0.5.
+        min_W (float, optional): Minimum W value.
+            W is between 0 and 1, small values lead to a rejection of the
+            normality assumption. Ref: https://www.nrc.gov/docs/ML1714/ML17143A100.pdf
+            Default to 0.5.
+    Raises:
+        UserValueError: time series has more than the maximum number of datapoints allowed for this test.
+        UserValueError: time series is not normally distributed.
+    """
+    if len(series) > max_data_points:
+        raise UserValueError(f"This time series exceeds the limit of {max_data_points} datapoints to perform the test.")
+
+    W, p_value = shapiro(series)
+
+    if p_value < min_p_value or W < min_W:
+        raise UserValueError("This time series is not normally distibuted")
+
+    return  # type: ignore
+
+
+def z_scores_test(x: np.array, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater") -> np.array:
+    """Z-scores Test
+
+    This functions performs a z-scores test given a cutoff value and returns a binary time series.
+
+    Args:
+        x (np.array): Data values.
+        cutoff (float, optional): Cut-off
+            Number of standard deviations from the mean.
+        direction (str, optional): Direction of the test.
+            Options:
+                "greater": the function will check if the z-scores are greater than the cutoff
+                "less": the function will check if the z-scores are less than the cutoff
+    Returns:
+         np.array: Binary np.array with the results of the test.
+            1 values indicate that the test has passed.
+    """
+    if (std := x.std()) == 0.0:
+        z_scores = np.zeros(len(x))
+    else:
+        z_scores = (x - x.mean()) / std
+
+    return threshold_test(z_scores, cutoff, direction)
+
+
+def modified_z_scores_test(
+    x: np.array, cutoff: float = 3.0, direction: Literal["greater", "less"] = "greater"
+) -> np.array:
+    """Z-scores Test
+
+    This functions performs a modified z-scores test given a cutoff value and returns a binary time series.
+
+    Args:
+        x (np.array): Data values.
+        cutoff (float, optional): Cut-off value.
+        direction (str, optional): Direction of the test.
+            Options:
+                "greater": the function will check if the modified z-scores are greater than the cutoff
+                "less": the function will check if the modified z-scores are less than the cutoff
+    Returns:
+         np.array: Binary np.array with the results of the test.
+            1 values indicate that the test has passed.
+    """
+
+    median = np.median(x)
+    if (mad := np.median(np.abs(x - median))) == 0.0:
+        modified_z_scores = np.zeros(len(x))
+    else:
+        modified_z_scores = 0.6745 * (x - median) / mad
+
+    return threshold_test(modified_z_scores, cutoff, direction)
+
+
+def iqr_test(
+    x: np.array, limit: Literal["upper", "lower"] = "upper", direction: Literal["greater", "less"] = "greater"
+) -> np.array:
+    """Z-scores Test
+
+    This functions performs a iqr test and returns a binary time series.
+
+    Args:
+        x (np.array): Data values.
+        limit (str, optional): Cut off limit.
+        direction (str, optional): Direction of the test.
+            Options:
+                "greater": the function will check if the values are greater than the cutoff limit.
+                "less": the function will check if the values are less than the cutoff limit.
+    Returns:
+         np.array: Binary np.array with the results of the test.
+            1 values indicate that the test has passed.
+    """
+
+    percentile25 = np.quantile(x, 0.25)
+    percentile75 = np.quantile(x, 0.75)
+    iqr = percentile75 - percentile25
+
+    if limit == "upper":
+        cutoff = percentile75 + 1.5 * iqr
+    elif limit == "lower":
+        cutoff = percentile25 - 1.5 * iqr
+
+    return threshold_test(x, cutoff, direction)
+
+
+def threshold_test(x: np.array, cutoff: float, direction: Literal["greater", "less"]) -> np.array:
+    """Threshold test
+
+    This functions performs a threshold test based on a direction (greater than or less than).
+
+    Args:
+        x (np.array): Data values.
+        cutoff (float): Cut-off value.
+        direction (str): Direction of the test.
+            Options:
+                "greater": the function will check if the values are greater than the cutoff limit.
+                "less": the function will check if the values are less than the cutoff limit.
+    Returns:
+         np.array: Binary np.array with the results of the test.
+            1 values indicate that the test has passed.
+    """
+    if direction == "greater":
+        return np.where(x > cutoff, 1, 0)
+    elif direction == "less":
+        return np.where(x < cutoff, 1, 0)
